@@ -23,7 +23,7 @@ Host %(keyname)s
   User %(user)s
 """
 
-ssh_file_path = os.path.expanduser('~/.ssh/config')
+ssh_config_path = os.path.expanduser('~/.ssh/config')
 
 
 class SSHRecipe(RecipeStandard):
@@ -41,12 +41,17 @@ class SSHRecipe(RecipeStandard):
             self.__call_command(config['target']['command'], ssh_path)
 
     def deactivate(self, feature_name, config):
+        ssh_path = os.path.join(self.directory.install_directory(feature_name), 
+                                config['keyname'])
         self.__install_ssh_config(config, ssh_path)
 
     def activate(self, feature_name, config):
+        ssh_path = os.path.join(self.directory.install_directory(feature_name), 
+                                config['keyname'])
         self.__install_ssh_config(config, ssh_path)
 
     def destroy(self, feature_name, config):
+        ssh_path = self.__generate_key(feature_name, config)
         super(SSHRecipe, self).destroy(feature_name, config)
 
     def __generate_key(self, feature_name, config):
@@ -68,17 +73,19 @@ class SSHRecipe(RecipeStandard):
         """        
         config['ssh_path'] = ssh_path
         ssh_config_injection = ssh_config_template % config
-        if os.path.exists(ssh_file_path):
-            ssh_contents =  open(ssh_file_path, "r+").read()
+        if os.path.exists(ssh_config_path):
+            ssh_contents =  open(ssh_config_path, "r+").read()
             if ssh_contents.find(config['host']) != -1 and \
-              not self.injections.injected(ssh_file_path):
+              not self.injections.injected(ssh_config_path):
                 self.logger.info("SSH config for %s already exists! Override?")
                 self.logger.info("Your existing config will not be overwritten, simply inactive.")
                 overwrite = lib.prompt("Override?", boolean=True, default="no")
                 if overwrite:
-                    self.injections.inject(ssh_file_path, ssh_config_injection)
+                    self.injections.inject(ssh_config_path, ssh_config_injection)
             else:
-                self.injections.inject(ssh_file_path, ssh_config_injection)
+                self.injections.inject(ssh_config_path, ssh_config_injection)
+        else:
+            self.injections.inject(ssh_config_path, ssh_config_injection)
         self.injections.commit()
 
     def __call_command(self, command, ssh_path):
